@@ -2,7 +2,7 @@ from flask import Flask, render_template, make_response
 from printedQr_ import printedQr
 
 app = Flask(__name__)
-app.config['DEBUG'] = True
+app.config['DEBUG'] = False
 
 
 @app.route('/', methods=['GET'])
@@ -16,7 +16,7 @@ def index():
 def getQr(text, scale=4):
     qr = printedQr.QRGen(scale=scale, data=text)
     qr.make_qr()
-    response = make_response(qr.make_scad)
+    response = make_response(qr.make_scad())
     response.headers['Content-Type'] = 'application/octect-stream'
     response.headers['Content-Disposition'] = 'attachment; filename=Qr' +  \
         text[:3] + '.scad'
